@@ -5,6 +5,7 @@ function (x, y, tau = 0.5, method = "sfn", rhs = NULL, control, ...)
     else tau <- 0.5
     fit <- switch(method,
 	sfn = rq.fit.sfn(x, y, tau = tau,  rhs = rhs, control = control, ...),
+	lasso = rq.fit.sfn(x, y, tau = tau,  rhs = rhs, control = control, ...),
         sfnc = rq.fit.sfnc(x, y, tau = tau,  rhs = rhs, control = control, ...), {
             what <- paste("rq.fit.", method, sep = "")
             if (exists(what, mode = "function"))
@@ -480,8 +481,8 @@ list(x=x,y=y,F=z, dummies = dummies)
     z <- .Fortran("penalty", as.integer(n), as.integer(m), as.integer(q),
         as.double(x), as.double(y), as.integer(bnd),as.integer(tri$tlist),
         as.integer(tri$tlptr), as.integer(tri$tlend), rax = double(m),
-	jax = integer(m), ned = integer(1), as.double(eps), ierr = integer(1),
-	PACKAGE = "quantreg")[c("rax", "jax", "iax", "ned", "ierr")]
+	jax = integer(m), ned = integer(1), as.double(eps), 
+	ierr = integer(1))[c("rax", "jax", "iax", "ned", "ierr")]
     if (z$ierr == 1)
         stop("collinearity in ggap")
     nnz <- 4 * z$ned
@@ -799,7 +800,19 @@ resid.rqss <- function(object, ...) object$resid[1:object$n]
             X <- X * weights
             Y <- Y * weights
         }
-        fit <- rqss.fit(X, Y, tau = tau,  rhs = rhs, control = control, ...)
+	XpX <- t(X) %*% X
+        nnzdmax <- XpX@ia[length(XpX@ia)] - 1
+        if (is.null(control[["nsubmax"]]))
+            control[["nsubmax"]] <- max(nnzdmax, floor(1000 +
+                exp(-1.6) * nnzdmax^1.2))
+        if (is.null(control[["nnzlmax"]]))
+            control[["nnzlmax"]] <- floor(2e+05 - 2.8 * nnzdmax +
+                7e-04 * nnzdmax^2)
+        if (is.null(control[["tmpmax"]]))
+            control[["tmpmax"]] <- floor(1e+05 + exp(-12.1) *
+                nnzdmax^2.35)
+        fit <- rqss.fit(X, Y, tau = tau,  rhs = rhs, control = control, 
+			method = method, ...)
         fit$nrA <- nrA
     }
     names(fit$coef) <- vnames
@@ -841,6 +854,7 @@ resid.rqss <- function(object, ...) object$resid[1:object$n]
     ncA <- object$ncA
     nrL <- object$nrL
     tau <- object$tau
+    cntl <- object$control
     X <- object$X
     p <- ncol(object$X)
     m <- length(ncA)
@@ -855,7 +869,8 @@ resid.rqss <- function(object, ...) object$resid[1:object$n]
         (quantile(uhat, 0.75) - quantile(uhat, 0.25))/1.34))
     f <- c(dnorm(uhat/h)/h,rep(1, length(resid) - n))
     D <- t(X) %*% (f * X)
-    D <- chol(.5 * (D + t(D)), ...)
+    D <- chol(.5 * (D + t(D)), nsubmax = cntl$nsubmax,
+             nnzlmax = cntl$nnzlmax, tmpmax = cntl$tmpmax)
     D <- backsolve(D,diag(p))
     D0 <- tau * (1 - tau) * t(X) %*% X
     V <- D %*% D0 %*% D
